@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11500 2019-04-30 18:49:58Z Lavender $
+# $Id: __init__.py 11589 2019-05-28 17:47:23Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-05-01 03:49:58 +0900 (週三, 01 五月 2019) $
-# $Revision: 11500 $
+# $Date: 2019-05-29 02:47:23 +0900 (週三, 29 五月 2019) $
+# $Revision: 11589 $
 
 import os
 import sys
@@ -94,9 +94,13 @@ def attachSettings(settingsDict):
         'Zephyrus.landing',
         'Zephyrus.facebook',
         'Zephyrus.line',
-        #'drip',
-        #'Zephyrus.autoresponder',
+        'Zephyrus.comment',
+        'Zephyrus.statistics',
+        'drip',
+        'Zephyrus.autoresponder',
         'robots',
+        'django_gravatar',
+        'captcha',
     ]
 
     if ZEPHYRUS_BLOG_ENABLE:
@@ -114,16 +118,13 @@ def attachSettings(settingsDict):
             
             'django.contrib.redirects',
             'Zephyrus.blog_extension',
-            'Zephyrus.comment',
-            'django_gravatar',
-            'captcha',
         ]
 
     if ZEPHYRUS_OSCAR_ENABLE:
         ADDING_INSTALLED_APPS += [
             'Zephyrus.cms_oscar',
         ]
-
+    
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('djangocms_')]
     extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
