@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: get_template.py 10626 2017-12-10 09:05:41Z Lavender $
+# $Id: get_template.py 11436 2019-04-10 17:56:15Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
-# $Revision: 10626 $
+# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
+# $Revision: 11436 $
 
 import os
 import shutil
@@ -31,15 +31,14 @@ class Command(BaseCommand):
 
     help = 'Copy html to templates and copy static files to static.'
     args = '<destination folder>'
+    
+    def add_arguments(self, parser):
+        parser.add_argument('path', type=str, help="template folder")
 
     def handle(self, *args, **options):
         try:
-            if len(args) < 1:
-                raise CommandError(
-                    "You must specify a folder to get template."
-                    )
-
-            path = args[0]
+            
+            path = options['path']
 
             try:
                 shutil.rmtree(TEMPLATES_DIR_PATH)
