@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11520 2019-05-04 18:14:05Z Lavender $
+# $Id: views.py 11593 2019-05-29 06:23:49Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,9 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-05 03:14:05 +0900 (週日, 05 五月 2019) $
-# $Revision: 11520 $
+# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
+# $Revision: 11593 $
 
+import json
 import six
 import urllib
 
@@ -22,13 +23,17 @@ from django.views.generic import View, FormView
 from django.contrib import messages
 from django.conf import settings
 from django.core.mail import send_mail
+from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
 from django.contrib.auth.decorators import permission_required
 from django.shortcuts import redirect, get_object_or_404
 from django.contrib.auth import get_user_model
 
 from Iuppiter.Encoding import utf8
+from Zephyrus.facebook import settings as FBSettings
+from Zephyrus.facebook import getCommentURL
 from Zephyrus.comment.models import Comment, CommentPlugin
 from Zephyrus.comment.forms import CommentForm
 
@@ -111,4 +116,43 @@ class CommentHideView(View):
             comment.display = False
             comment.save()
         return redirect(comment.url)
+
+class CommentWebHookView(View):
+    def get(self, request, *args, **kwargs):
+        verify = request.GET.get('hub.verify_token')
+        if verify == FBSettings.ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN:
+            return HttpResponse(request.GET.get('hub.challenge'))
+        else:
+            return HttpResponse('Error, invalid token')
+        
+    @method_decorator(csrf_exempt)
+    def dispatch(self, request, *args, **kwargs):
+        return super(
+            CommentWebHookView, self).dispatch(request, *args, **kwargs)
+
+    def post(self, request, *args, **kwargs):
+        msg = request.body.decode('utf-8')
+        
+        data = json.loads(msg)
+
+        entry = data.get("entry")
+        if entry:
+            for e in entry:
+                changes = e.get("changes")
+                if changes:
+                    for c in changes:
+                        field = c.get("field")
+                        message = c.get("value", {}).get("message")
+                        mid = c.get("value", {}).get("id")
+                        name = c.get("value", {}).get("from", {}).get("name")
+                        if field == "plugin_comment":
+                            url = getCommentURL(mid)
+                            comment = Comment.objects.create(
+                                url=url,
+                                message=message,
+                                facebook=True,
+                                facebookUser=name,
+                            )
+   
+        return HttpResponse('Success')
         
\ No newline at end of file
