@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: __init__.py 11593 2019-05-29 06:23:49Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
+# $Revision: 11593 $
+
+import json
+import requests
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
 
 class settings(object):
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
+    ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
+    ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
+    
     ZEPHYRUS_FACEBOOK_FAN_DEFAULT_TEMPLATE = \
         "facebook/FacebookFanPlugin.html"
     ZEPHYRUS_FACEBOOK_PHOTO_DEFAULT_TEMPLATE = \
@@ -41,3 +48,21 @@ class settings(object):
         for ele in _settings.ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES:
             if not ele[0] == "facebook/FacebookPhotoPlugin.html":
                 ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES.append(ele)
+
+def getCommentURL(commentId, 
+    key=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, 
+    value=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET):
+
+    accessToken = '%s|%s' % (key, value)
+    url = ("https://graph.facebook.com/v3.3/"
+           "%s?fields=permalink_url&access_token=%s") % (commentId, accessToken)
+    result = requests.get(url)
+    data = json.loads(result.text)
+
+    url = data.get("permalink_url")
+
+    if url:
+        return url[:url.index("?")]
+    else:
+        return None
+
