@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11178 2018-07-22 12:34:44Z Lavender $
+# $Id: models.py 11590 2019-05-28 18:28:03Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-07-22 21:34:44 +0900 (週日, 22 七月 2018) $
-# $Revision: 11178 $
+# $Date: 2019-05-29 03:28:03 +0900 (週三, 29 五月 2019) $
+# $Revision: 11590 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -100,7 +100,8 @@ class ShareLike(CMSPlugin):
 
     showFaces = models.BooleanField(_("Show faces"),)
     share = models.BooleanField(_("Share"),)
-    appId = models.CharField(_("Facebook API app ID"), max_length=20)
+    appId = models.CharField(
+        _("Facebook API app ID"), max_length=20, null=True, blank=True)
 
     width = models.PositiveIntegerField(_("Width"), default=450)
     height = models.PositiveIntegerField(_("Height"), default=80)
@@ -113,7 +114,8 @@ TAB_CHOICE = (
 
 class FanPage(CMSPlugin):
     url = models.URLField()
-    appId = models.CharField(_("Facebook API app ID"), max_length=20)
+    appId = models.CharField(
+        _("Facebook API app ID"), max_length=20, null=True, blank=True)
 
     width = models.PositiveIntegerField(
         _("Width"), 
